aboutsummaryrefslogtreecommitdiffstats
path: root/epan/proto.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/proto.h')
-rw-r--r--epan/proto.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/epan/proto.h b/epan/proto.h
index 005ad4b625..3fef7b00bf 100644
--- a/epan/proto.h
+++ b/epan/proto.h
@@ -3,8 +3,8 @@
*
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
@@ -51,7 +51,7 @@
#include "tvbuff.h"
#include "ftypes/ftypes.h"
/** The header-field index for the special text pseudo-field. Exported by libethereal.dll */
ETH_VAR_IMPORT int hf_text_only;
/** the maximum length of a protocol field string representation */
@@ -208,7 +208,7 @@ typedef struct field_info {
* used in field_info.flags. */
/* HIDING PROTOCOL FIELDS IS DEPRECATED, IT'S CONSIDERED TO BE BAD GUI DESIGN! */
#define FI_HIDDEN 0x0001
-/** The protocol field should be displayed as "generated by Ethereal",
+/** The protocol field should be displayed as "generated by Wireshark",
* used in field_info.flags. */
#define FI_GENERATED 0x0002
@@ -283,10 +283,10 @@ typedef proto_node proto_item;
/* HIDING PROTOCOL FIELDS IS DEPRECATED, IT'S CONSIDERED TO BE BAD GUI DESIGN! */
#define PROTO_ITEM_SET_HIDDEN(proto_item) \
((proto_item) ? FI_SET_FLAG((proto_item)->finfo, FI_HIDDEN) : 0)
-/** is this protocol field generated by Ethereal (and not read from the packet data)? */
+/** is this protocol field generated by Wireshark (and not read from the packet data)? */
#define PROTO_ITEM_IS_GENERATED(proto_item) \
((proto_item) ? FI_GET_FLAG((proto_item)->finfo, FI_GENERATED) : 0)
-/** mark this protocol field as generated by Ethereal (and not read from the packet data) */
+/** mark this protocol field as generated by Wireshark (and not read from the packet data) */
#define PROTO_ITEM_SET_GENERATED(proto_item) \
((proto_item) ? FI_SET_FLAG((proto_item)->finfo, FI_GENERATED) : 0)
@@ -1495,11 +1495,11 @@ extern void proto_registrar_dump_fields(int format);
/** Points to the first element of an array of Booleans, indexed by
a subtree item type. That array element is TRUE if subtrees of
an item of that type are to be expanded. With MSVC and a
- libethereal.dll, we need a special declaration. */
+ libwireshark.dll, we need a special declaration. */
ETH_VAR_IMPORT gboolean *tree_is_expanded;
/** Number of elements in the tree_is_expanded array. With MSVC and a
* libethereal.dll, we need a special declaration. */
ETH_VAR_IMPORT int num_tree_types;
/** glib doesn't have g_ptr_array_len of all things!*/
@@ -51,7 +51,7 @@
#include "tvbuff.h"
#include "ftypes/ftypes.h"
-/** The header-field index for the special text pseudo-field. Exported by libethereal.dll */
+/** The header-field index for the special text pseudo-field. Exported by libwireshark.dll */
ETH_VAR_IMPORT int hf_text_only;
/** the maximum length of a protocol field string representation */
@@ -1495,11 +1495,11 @@ extern void proto_registrar_dump_fields(int format);
ETH_VAR_IMPORT gboolean *tree_is_expanded;
/** Number of elements in the tree_is_expanded array. With MSVC and a
- * libethereal.dll, we need a special declaration. */
+ * libwireshark.dll, we need a special declaration. */
ETH_VAR_IMPORT int num_tree_types;
/** glib doesn't have g_ptr_array_len of all things!*/